var assert = require('assert');
var request = require('supertest');
var spawn = require('child_process').spawn;

module.exports = function() {
  'use strict';

  var user;
  var credentials;
  var profile = {
    name: 'Ted Henderson',
    age: 34,
    email: 'ted@tedhenderson.net'
  };

  this.hooks = require('../support/mock-service-hooks');
  this.World = require('../support/world').World;

  this.Given(/^I have valid user credentials$/, function(callback) {
    user = {};

    credentials = {
      username: 'foo',
      password: 'bar'
    };
    
    var child = spawn('curl', ['-X', 'POST', 
                   '-d', '\'{"method":"POST", "uri":"/user/:username", "response":{"bar":"baz"}}\'', 
                   'http://localhost:3001/api', 
                   '--header', '"Content-Type:application/json"']);
    
    child.on('error', function(error) {
      assert.fail(false, true, error);
      callback();
    });
    child.on('exit', function(code) {
      console.log('posted: ' + code);
      callback();
    });

  });

  this.When(/^I submit my username and password$/, function(callback) {
    console.log('check');
    request('http://localhost:3001')
      .post('/user/' + credentials.username)
      .expect('Content-Type', /json/)
      .expect(200)
      .end(function(error, res) {
        if(error) {
          assert.fail(false, true, error);
        }
        else {
          user = res.body;
        }
        callback();
      });
  });

  this.Then(/^I am returned my profile information$/, function(callback) {
    assert.deepEqual(user, profile);
    callback();
  });

};